@@ -25,10 +25,10 @@ class Moony_Action
      * 
      * @access public
      * @abstract
-     * @param object $context コンテキスト格納クラス
-     * @param object $view ビュークラス
+     * @param object $request リクエスト情報
+     * @param object $response レスポンス情報
      */
-    function execute($context, $view)
+    function execute($request, $response)
     {
     }
 }
